@@ -186,7 +186,7 @@ def run(handler: PoeHandler, api_key: str = "") -> None:
     app.add_exception_handler(RequestValidationError, exception_handler)
 
     global auth_key
-    auth_key = api_key if api_key else os.environ.get("POE_API_KEY", "")
+    auth_key = api_key if api_key else os.environ.get("POE_API_KEY", None)
 
     @app.get("/")
     async def index() -> Response:
